==> synonyms-2.1.1.tar.gz: synonyms/modules/synonyms_autocomplete/tests/src/Functional/AdminFunctionalityTest.php <==
<?php

namespace Drupal\Tests\synonyms_autocomplete\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Checks if admin functionality works correctly.
 *
 * @group synonyms
 */
class AdminFunctionalityTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'synonyms',
    'synonyms_autocomplete',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->container->get('router.builder')->rebuild();

    // Log in an admin user.
    $account = $this->drupalCreateUser([
      'administer site configuration',
      'administer synonyms',
    ]);
    $this->drupalLogin($account);
  }

  /**
   * Make sure the main admin page loads correctly.
   *
   * It should contain the default Autocomplete widget wording.
   */
  public function testSynonymsAdmin() {
    // Load the main admin page.
    $this->drupalGet('admin/structure/synonyms');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Synonyms configuration');
    $session->pageTextContains('Default wordings:');
    $session->pageTextContains('Synonyms-friendly autocomplete widget: @synonym is the @field_label of @entity_label');

    // Load the autocomplete widget settings page.
    $this->drupalGet('admin/structure/synonyms_autocomplete/settings');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Synonyms autocomplete widget settings');
    $session->pageTextContains('Default wording');
    $session->fieldValueEquals('default_wording', '@synonym is the @field_label of @entity_label');
    $session->pageTextContains('Specify the wording');
    $session->pageTextContains('@field_label: The lowercase label of the provider field');
    $session->pageTextContains('This will also serve as a fallback wording');
    $session->buttonExists('Save configuration');

    // Edit settings.
    $edit = [
      'default_wording' => 'Test wording',
    ];
    $this->submitForm($edit, 'Save');

    // Confirm the change.
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->addressEquals('admin/structure/synonyms_autocomplete/settings');
    $session->pageTextContains('Synonyms autocomplete widget settings');
    $session->fieldValueEquals('default_wording', 'Test wording');
    $session->buttonExists('Save configuration');

    // Confirm the change at the main admin page.
    $this->drupalGet('admin/structure/synonyms');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Synonyms configuration');
    $session->pageTextContains('Default wordings:');
    $session->pageTextContains('Synonyms-friendly autocomplete widget: Test wording');

    // Load the Manage behaviors page for User entity type.
    $this->drupalGet('admin/structure/synonyms/behavior/user/user');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Manage behaviors of User');
    $session->pageTextContains('Autocomplete service');
    $session->checkboxNotChecked('autocomplete_status');
    $session->buttonExists('Save configuration');

    // Edit settings.
    $edit = [
      'autocomplete_status' => 1,
    ];
    $this->submitForm($edit, 'Save');

    // Confirm the change.
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->addressEquals('admin/structure/synonyms/behavior/user/user');
    $session->pageTextContains('Manage behaviors of User');
    $session->pageTextContains('Autocomplete service');
    $session->checkboxChecked('autocomplete_status');
    $session->buttonExists('Save configuration');
  }

}

==> synonyms-2.1.4.tar.gz: synonyms/modules/synonyms_autocomplete/tests/src/Functional/AdminFunctionalityTest.php <==
<?php

namespace Drupal\Tests\synonyms_autocomplete\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Checks if admin functionality works correctly.
 *
 * @group synonyms
 */
class AdminFunctionalityTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'synonyms',
    'synonyms_autocomplete',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();
    $this->container->get('router.builder')->rebuild();

    // Log in an admin user.
    $account = $this->drupalCreateUser([
      'administer site configuration',
      'administer synonyms',
    ]);
    $this->drupalLogin($account);
  }

  /**
   * Make sure the main admin page loads correctly.
   *
   * It should contain the default Autocomplete widget wording.
   */
  public function testSynonymsAdmin() {
    // Load the main admin page.
    $this->drupalGet('admin/structure/synonyms');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Synonyms configuration');
    $session->pageTextContains('Default wordings:');
    $session->pageTextContains('Synonyms-friendly autocomplete widget: @synonym is the @field_label of @entity_label');

    // Load the autocomplete widget settings page.
    $this->drupalGet('admin/structure/synonyms_autocomplete/settings');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Synonyms autocomplete widget settings');
    $session->pageTextContains('Default wording');
    $session->fieldValueEquals('default_wording', '@synonym is the @field_label of @entity_label');
    $session->pageTextContains('Specify the wording');
    $session->pageTextContains('@field_label: The lowercase label of the provider field');
    $session->pageTextContains('This will also serve as a fallback wording');
    $session->buttonExists('Save configuration');

    // Edit settings.
    $edit = [
      'default_wording' => 'Test wording',
    ];
    $this->submitForm($edit, 'Save');

    // Confirm the change.
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->addressEquals('admin/structure/synonyms_autocomplete/settings');
    $session->pageTextContains('Synonyms autocomplete widget settings');
    $session->fieldValueEquals('default_wording', 'Test wording');
    $session->buttonExists('Save configuration');

    // Confirm the change at the main admin page.
    $this->drupalGet('admin/structure/synonyms');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Synonyms configuration');
    $session->pageTextContains('Default wordings:');
    $session->pageTextContains('Synonyms-friendly autocomplete widget: Test wording');

    // Load the Manage behaviors page for User entity type.
    $this->drupalGet('admin/structure/synonyms/behavior/user/user');
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->pageTextContains('Manage behaviors of User');
    $session->pageTextContains('Autocomplete service');
    $session->checkboxNotChecked('autocomplete_status');
    $session->buttonExists('Save configuration');

    // Edit settings.
    $edit = [
      'autocomplete_status' => 1,
    ];
    $this->submitForm($edit, 'Save');

    // Confirm the change.
    $session = $this->assertSession();
    $session->statusCodeEquals(200);
    $session->addressEquals('admin/structure/synonyms/behavior/user/user');
    $session->pageTextContains('Manage behaviors of User');
    $session->pageTextContains('Autocomplete service');
    $session->checkboxChecked('autocomplete_status');
    $session->buttonExists('Save configuration');
  }

}
